import { cx, css } from '@emotion/css';
import { useDialog } from '@react-aria/dialog';
import { FocusScope } from '@react-aria/focus';
import { useOverlay } from '@react-aria/overlays';
import RcDrawer from 'rc-drawer';
import React__default, { useEffect } from 'react';
import { useClickAway } from 'react-use';
import { selectors } from '@grafana/e2e-selectors';
import { useStyles2 } from '../../themes/ThemeContext.js';
import '@grafana/data';
import 'memoize-one';
import '@emotion/react';
import 'tinycolor2';
import { Button } from '../Button/Button.js';
import '../Button/ButtonGroup.js';
import { CustomScrollbar } from '../CustomScrollbar/CustomScrollbar.js';
import { Text } from '../Text/Text.js';

var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
function Drawer({
  children,
  onClose,
  closeOnMaskClick = true,
  scrollableContent = false,
  title,
  subtitle,
  width,
  size = "md",
  tabs
}) {
  const styles = useStyles2(getStyles);
  const overlayRef = React__default.useRef(null);
  const { dialogProps, titleProps } = useDialog({}, overlayRef);
  const { overlayProps } = useOverlay(
    {
      isDismissable: false,
      isOpen: true,
      onClose
    },
    overlayRef
  );
  useBodyClassWhileOpen();
  useClickAway(overlayRef, closeOnMaskClick ? onClose : doNothing);
  const rootClass = cx(styles.drawer, !width && styles.sizes[size]);
  const content = /* @__PURE__ */ React__default.createElement("div", { className: styles.content }, children);
  return /* @__PURE__ */ React__default.createElement(
    RcDrawer,
    {
      open: true,
      onClose,
      placement: "right",
      width: width != null ? width : "",
      getContainer: ".main-view",
      className: styles.drawerContent,
      rootClassName: rootClass,
      motion: {
        motionAppear: true,
        motionName: styles.drawerMotion
      },
      maskClassName: styles.mask,
      maskClosable: closeOnMaskClick,
      maskMotion: {
        motionAppear: true,
        motionName: styles.maskMotion
      }
    },
    /* @__PURE__ */ React__default.createElement(FocusScope, { restoreFocus: true, contain: true, autoFocus: true }, /* @__PURE__ */ React__default.createElement(
      "div",
      __spreadProps(__spreadValues(__spreadValues({
        "aria-label": typeof title === "string" ? selectors.components.Drawer.General.title(title) : selectors.components.Drawer.General.title("no title"),
        className: styles.container
      }, overlayProps), dialogProps), {
        ref: overlayRef
      }),
      typeof title === "string" && /* @__PURE__ */ React__default.createElement("div", { className: cx(styles.header, Boolean(tabs) && styles.headerWithTabs) }, /* @__PURE__ */ React__default.createElement("div", { className: styles.actions }, /* @__PURE__ */ React__default.createElement(
        Button,
        {
          icon: "times",
          variant: "secondary",
          fill: "text",
          onClick: onClose,
          "aria-label": selectors.components.Drawer.General.close
        }
      )), /* @__PURE__ */ React__default.createElement("div", { className: styles.titleWrapper }, /* @__PURE__ */ React__default.createElement(Text, __spreadValues({ as: "h3" }, titleProps), title), subtitle && /* @__PURE__ */ React__default.createElement("div", { className: styles.subtitle }, subtitle), tabs && /* @__PURE__ */ React__default.createElement("div", { className: styles.tabsWrapper }, tabs))),
      typeof title !== "string" && title,
      /* @__PURE__ */ React__default.createElement("div", { className: styles.contentScroll }, !scrollableContent ? content : /* @__PURE__ */ React__default.createElement(CustomScrollbar, { autoHeightMin: "100%" }, content))
    ))
  );
}
function doNothing() {
}
function useBodyClassWhileOpen() {
  useEffect(() => {
    if (!document.body) {
      return;
    }
    document.body.classList.add("body-drawer-open");
    return () => {
      document.body.classList.remove("body-drawer-open");
    };
  }, []);
}
const getStyles = (theme) => {
  return {
    container: css`
      display: flex;
      flex-direction: column;
      height: 100%;
      flex: 1 1 0;
    `,
    drawer: css`
      .main-view & {
        top: 81px;
      }

      .main-view--search-bar-hidden & {
        top: 41px;
      }

      .rc-drawer-content-wrapper {
        box-shadow: ${theme.shadows.z3};

        ${theme.breakpoints.down("sm")} {
          width: calc(100% - ${theme.spacing(2)}) !important;
          min-width: 0 !important;
        }
      }
    `,
    sizes: {
      sm: css({
        ".rc-drawer-content-wrapper": {
          label: "drawer-sm",
          width: "25vw",
          minWidth: theme.spacing(48)
        }
      }),
      md: css({
        ".rc-drawer-content-wrapper": {
          label: "drawer-md",
          width: "50vw",
          minWidth: theme.spacing(60)
        }
      }),
      lg: css({
        ".rc-drawer-content-wrapper": {
          label: "drawer-lg",
          width: "75vw",
          minWidth: theme.spacing(93),
          [theme.breakpoints.down("md")]: {
            width: `calc(100% - ${theme.spacing(2)}) !important`,
            minWidth: 0
          }
        }
      })
    },
    drawerContent: css`
      background-color: ${theme.colors.background.primary} !important;
      display: flex;
      flex-direction: column;
      overflow: hidden;
      z-index: ${theme.zIndex.dropdown};
    `,
    drawerMotion: css`
      &-appear {
        transform: translateX(100%);
        transition: none !important;

        &-active {
          transition: ${theme.transitions.create("transform")} !important;
          transform: translateX(0);
        }
      }
    `,
    mask: css`
      background-color: ${theme.components.overlay.background} !important;
      backdrop-filter: blur(1px);
    `,
    maskMotion: css`
      &-appear {
        opacity: 0;

        &-active {
          opacity: 1;
          transition: ${theme.transitions.create("opacity")};
        }
      }
    `,
    header: css({
      flexGrow: 0,
      padding: theme.spacing(3, 2),
      borderBottom: `1px solid ${theme.colors.border.weak}`
    }),
    headerWithTabs: css({
      borderBottom: "none"
    }),
    actions: css({
      position: "absolute",
      right: theme.spacing(1),
      top: theme.spacing(2)
    }),
    titleWrapper: css`
      overflow-wrap: break-word;
    `,
    subtitle: css({
      color: theme.colors.text.secondary,
      paddingTop: theme.spacing(1)
    }),
    content: css({
      padding: theme.spacing(2),
      height: "100%",
      flexGrow: 1
    }),
    contentScroll: css({
      minHeight: 0,
      flex: 1
    }),
    tabsWrapper: css({
      paddingLeft: theme.spacing(2),
      margin: theme.spacing(2, -1, -3, -3)
    })
  };
};

export { Drawer };
//# sourceMappingURL=Drawer.js.map
