import { useLayoutEffect } from 'react';
import { pluginLog } from '../utils.js';

const MIN_ZOOM_DIST = 5;
const ZoomPlugin = ({ onZoom, config }) => {
  useLayoutEffect(() => {
    config.addHook("setSelect", (u) => {
      const min = u.posToVal(u.select.left, "x");
      const max = u.posToVal(u.select.left + u.select.width, "x");
      if (u.select.width >= MIN_ZOOM_DIST) {
        pluginLog("ZoomPlugin", false, "selected", {
          min,
          max,
          bbox: {
            left: u.bbox.left / window.devicePixelRatio + u.select.left,
            top: u.bbox.top / window.devicePixelRatio,
            height: u.bbox.height / window.devicePixelRatio,
            width: u.select.width
          }
        });
        onZoom({ from: min, to: max });
      }
      u.setSelect({ left: 0, width: 0 }, false);
    });
  }, [config]);
  return null;
};

export { ZoomPlugin };
//# sourceMappingURL=ZoomPlugin.js.map
