import { FieldType, TIME_SERIES_VALUE_FIELD_NAME } from '../types/dataFrame.js';
import { guessFieldTypeForField } from './processDataFrame.js';

class ArrayDataFrame {
  constructor(source, names) {
    this.fields = [];
    this.length = 0;
    return arrayToDataFrame(source, names);
  }
}
function arrayToDataFrame(source, names) {
  const df = {
    fields: [],
    length: source.length
  };
  if (!(source == null ? void 0 : source.length)) {
    return df;
  }
  if (names) {
    for (const name of names) {
      df.fields.push(
        makeFieldFromValues(
          name,
          source.map((v) => v[name])
        )
      );
    }
    return df;
  }
  const first = source.find((v) => v != null);
  if (first != null) {
    if (typeof first === "object") {
      df.fields = Object.keys(first).map((name) => {
        return makeFieldFromValues(
          name,
          source.map((v) => v[name])
        );
      });
    } else {
      df.fields.push(makeFieldFromValues(TIME_SERIES_VALUE_FIELD_NAME, source));
    }
  }
  return df;
}
function makeFieldFromValues(name, values) {
  var _a;
  const f = { name, config: {}, values, type: FieldType.other };
  f.type = (_a = guessFieldTypeForField(f)) != null ? _a : FieldType.other;
  return f;
}

export { ArrayDataFrame, arrayToDataFrame };
//# sourceMappingURL=ArrayDataFrame.js.map
