import { DataSourceRef as CommonDataSourceRef, DataSourceRef } from '../common/common.gen';
import * as raw from '../raw/dashboard/x/dashboard_types.gen';
import { DataQuery } from './common.types';
export type { CommonDataSourceRef as DataSourceRef };
export interface Panel<TOptions = Record<string, unknown>, TCustomFieldConfig = Record<string, unknown>> extends Omit<raw.Panel, 'fieldConfig'> {
    fieldConfig: FieldConfigSource<TCustomFieldConfig>;
}
export interface RowPanel extends Omit<raw.RowPanel, 'panels'> {
    panels: Array<Panel | raw.GraphPanel | raw.HeatmapPanel>;
}
export declare enum VariableHide {
    dontHide = 0,
    hideLabel = 1,
    hideVariable = 2
}
export interface VariableModel extends Omit<raw.VariableModel, 'hide' | 'description' | 'datasource'> {
    hide: VariableHide;
    description?: string | null;
    datasource: DataSourceRef | null;
}
export interface Dashboard extends Omit<raw.Dashboard, 'templating' | 'annotations' | 'thresholds' | 'panels'> {
    panels?: Array<Panel | RowPanel | raw.GraphPanel | raw.HeatmapPanel>;
    annotations?: AnnotationContainer;
    thresholds?: ThresholdsConfig;
    templating?: {
        list?: VariableModel[];
    };
}
export interface AnnotationQuery<TQuery extends DataQuery = DataQuery> extends Omit<raw.AnnotationQuery, 'target' | 'datasource'> {
    datasource?: DataSourceRef | null;
    target?: TQuery;
}
export interface AnnotationContainer extends Omit<raw.AnnotationContainer, 'list'> {
    list?: AnnotationQuery[];
}
export interface Threshold extends Omit<raw.Threshold, 'value'> {
    value: number | null;
}
export interface ThresholdsConfig extends Omit<raw.ThresholdsConfig, 'steps'> {
    steps: Threshold[];
}
export interface FieldConfig<TOptions = Record<string, unknown>> extends Omit<raw.FieldConfig, 'mappings'> {
    custom?: TOptions & Record<string, unknown>;
    mappings?: ValueMapping[];
}
export declare type ValueMapping = raw.ValueMap | RangeMap | raw.RegexMap | raw.SpecialValueMap;
export interface RangeMap extends Omit<raw.RangeMap, 'options'> {
    options: {
        from: number | null;
        to: number | null;
        result: raw.ValueMappingResult;
    };
}
export interface FieldConfigSource<TOptions = Record<string, unknown>> extends Omit<raw.FieldConfigSource, 'defaults'> {
    defaults: FieldConfig<TOptions>;
}
export interface MatcherConfig<TConfig = any> extends raw.MatcherConfig {
    options?: TConfig;
}
export interface DataTransformerConfig<TOptions = any> extends raw.DataTransformerConfig {
    options: TOptions;
}
export declare const defaultDashboard: Dashboard;
export declare const defaultVariableModel: VariableModel;
export declare const defaultPanel: Partial<Panel>;
export declare const defaultRowPanel: Partial<Panel>;
export declare const defaultFieldConfig: Partial<FieldConfig>;
export declare const defaultFieldConfigSource: Partial<FieldConfigSource>;
export declare const defaultMatcherConfig: Partial<MatcherConfig>;
export declare const defaultAnnotationQuery: Partial<AnnotationQuery>;
export declare const defaultAnnotationContainer: Partial<AnnotationContainer>;
export declare const defaultThresholdsConfig: Partial<ThresholdsConfig>;
